pytilities

Package pytilities |
[hide private]
[frames] | no frames]

# Package pytilities

source code

Root of pytilities, various utilities

Web site: http://pytilities.sourceforge.net/ Sourceforge site: http://sourceforge.net/projects/pytilities/

Features:

> - delegation: decorate classes with attributes that are delegated to a

> target object without having to write those attributes on the decorating class

> - event dispatching: Observer/Subject like event dispatching with wrappers

> for hiding events on dispatchers and combining dispatchers

> - function overloading
> - various: Vector, Rectangle classes, custom types, ...

Classes:

> - AttributeCollection: Abstract, represents a collection of attributes.
> - AttributeCollectionBase: Mixin, allows easy extension of class attributes
> - Stringifiable: Mixin, provides a reasonable default __str__

Functions:

> - mangle: Get the mangled name of an attribute

Submodules | [hide private]
pytilities.attributecollection pytilities.attributecollectionbase pytilities.delegation: Delegation utilities pytilities.delegation.decorators: Various decorators to ease delegation pytilities.delegation.delegator pytilities.delegation.delegatorfactory pytilities.delegation.profile pytilities.event: Delegation utilities pytilities.event.decorators: Various decorators to ease event dispatching. pytilities.event.dispatcher_ pytilities.event.dispatcherswitch pytilities.event.restricteddispatcher pytilities.geometry: All sorts of geometry trinkets pytilities.geometry.boundvector pytilities.geometry.immutablevector pytilities.geometry.rectangle pytilities.geometry.vector pytilities.geometry.verboserectangle pytilities.geometry.verbosevector pytilities.mangling pytilities.overloading: Function overloading tools. pytilities.overloading.compositeparameter pytilities.overloading.decorators pytilities.overloading.matchers pytilities.overloading.overload pytilities.overloading.overloader pytilities.overloading.parameter pytilities.stringifiable pytilities.test pytilities.test.attributecollection pytilities.test.delegation pytilities.test.delegation.delegation pytilities.test.delegation.profile pytilities.test.event pytilities.test.event.decorators pytilities.test.event.dispatcher pytilities.test.event.dispatcherswitch pytilities.test.event.helpers pytilities.test.event.restricteddispatcher pytilities.test.geometry pytilities.test.geometry.rectangle pytilities.test.geometry.vector pytilities.test.mangling pytilities.test.overloading pytilities.test.overloading.overloaded pytilities.test.overloading.parameter pytilities.testing: Test utilities pytilities.tests pytilities.types: Various types pytilities.types._numbertypemeta pytilities.types._numerictypemeta pytilities.types._sequencetypemeta pytilities.types.numbertype pytilities.types.numerictype pytilities.types.sequencetype

Variables | [hide private]
| __package__ = ``'``pytilities``'``